import { defineStore } from "pinia";
import { POST } from "../api";
import { useBudgetsStore } from "./budget";
import { CategoryGroup } from "./category-group";

interface State {
    Categories: Map<string, Category>;
}

export interface Category {
    ID: string;
    CategoryGroupID: string;
    Group: string;
    Name: string;
    AvailableLastMonth: number;
    Assigned: number;
    Activity: number;
}

export const useCategoryStore = defineStore("category", {
  state: (): State => ({
      Categories: new Map<string, Category>(),
  }),
  getters: {
    GetCategoriesForGroup(state) {
      return (group : CategoryGroup) : Category[] => {
        return [...state.Categories.values()].filter(x => x.CategoryGroupID == group.ID);
      }
    },
  },
  actions: {
    async CreateCategory(
      group: string,
      name: string,
    ) {
      const result = await POST(
        "/category/new",
        JSON.stringify({
          budgetId: useBudgetsStore().CurrentBudgetID,
          name: name,
          group: group,
        })
      );
      const response = await result.json();
      this.AddCategory(response);
    },
    async AddCategory(...categories : Category[]){
      for (const category of categories) {
        this.Categories.set(category.ID, category);
      }
    },
    async SetAssigned(category : Category, year : number, month : number, assigned : number){
      this.Categories.get(category.ID)!.Assigned = assigned;
      const currentBudgetID = useBudgetsStore().CurrentBudgetID;
      await POST("/budget/"+currentBudgetID+"/category/" + category.ID + "/" + year + "/" + (month+1),
        JSON.stringify({Assigned: assigned}));
    }
  },
});